@@ -10,7 +10,7 @@
 
 distHaversine <- function(p1, p2, r=6378137) {
 #* Haversine formula to calculate distance between two points specified by 
-#* from: Haversine formula - r. W. Sinnott, "Virtues of the Haversine",
+#* from: Haversine formula - R.W. Sinnott, "Virtues of the Haversine",
 #*  Sky and Telescope, vol 68, no 2, 1984
 #*  http:#//www.census.gov/cgi-bin/geo/gisfaq?Q5.1
 
@@ -18,13 +18,22 @@ distHaversine <- function(p1, p2, r=6378137) {
 # (c) 2002-2009 Chris Veness
 	toRad <- pi / 180 
 	p1 <- .pointsToMatrix(p1) * toRad
-	p2 <- .pointsToMatrix(p2) * toRad
+	if (missing(p2)) {
+		p2 <- p1[-1,]
+		p1 <- p1[-nrow(p1),]
+	} else {
+		p2 <- .pointsToMatrix(p2)  * toRad	
+	}
 
 	p = cbind(p1[,1], p1[,2], p2[,1], p2[,2], as.vector(r))
 		
 	dLat <- p[,4]-p[,2]
 	dLon <- p[,3]-p[,1]
 	a <- sin(dLat/2) * sin(dLat/2) + cos(p[,2]) * cos(p[,4]) * sin(dLon/2) * sin(dLon/2)
+	# to avoid values of 'a' that are a sliver above 1
+	# which may occur at antipodes
+	# https://stackoverflow.com/questions/45889616/why-does-disthaversine-return-nan-for-some-pairs-of-coordinates#
+	a <- pmin(a, 1)
 	dist <- 2 * atan2(sqrt(a), sqrt(1-a)) * p[,5]
 	return( as.vector(dist))
 }
