@@ -10,7 +10,13 @@ distVincentySphere <- function(p1, p2, r=6378137) {
 	toRad <- pi / 180 
 
 	p1 <- .pointsToMatrix(p1) * toRad
-	p2 <- .pointsToMatrix(p2) * toRad
+	if (missing(p2)) {
+		p2 <- p1[-1,]
+		p1 <- p1[-nrow(p1),]
+	} else {
+		p2 <- .pointsToMatrix(p2) * toRad
+	}
+	
 	p <- cbind(p1[,1], p1[,2], p2[,1], p2[,2], as.vector(r))	
 	
 	lon1 <- p[,1]
